@@ -239,6 +239,15 @@ yelp_search_parser_process (YelpSearchParser *parser, gchar *search_terms)
 
     parser->search_terms = decode_uri (search_terms);
 
+#ifdef ENABLE_BEAGLE
+    if (beagle_util_daemon_is_running()) {
+	beagle_client = beagle_client_new (NULL);
+	debug_print (DB_DEBUG, "client: %p\n", beagle_client);
+    } else {
+	beagle_client = NULL;
+    }
+#endif /* ENABLE_BEAGLE */
+
     parser->search_process_id = 
 	g_idle_add_full (G_PRIORITY_LOW,
 			 (GSourceFunc) search_parser_process_idle,
@@ -1080,7 +1089,10 @@ slow_search_process (RrnReg *reg, SearchDocData *data)
     container->doc_title = g_strdup ((gchar *) reg->name);
     container->score=0;
     container->html = FALSE;
-    container->default_snippet = g_strdup ((gchar *) reg->comment);
+    if (reg->comment)
+    	container->default_snippet = g_strdup ((gchar *) reg->comment);
+    else
+    	container->default_snippet = g_strdup (_("No Comment"));
     container->current_subsection = NULL;
     container->elem_type = NULL;
 
