@@ -179,6 +179,13 @@ resolve_full_file (const gchar *path)
 	} else if (resolve_is_man_path (path, "bz2")) {
 	    type = YELP_RRN_TYPE_MAN;
 	}
+    } else if (g_str_equal (mime_type, "application/x-lzma")) {
+ 	    if (g_str_has_suffix (path, ".info.lzma")) {
+ 		    type = YELP_RRN_TYPE_INFO;
+ 	    } else if (resolve_is_man_path (path, "lzma")) {
+ 		    type = YELP_RRN_TYPE_MAN;
+ 	    }
+
     } else if (g_str_equal (mime_type, "text/plain")) {
 	if (g_str_has_suffix (path, ".info")) {
 	    type = YELP_RRN_TYPE_INFO;
@@ -216,7 +223,7 @@ resolve_man_page (const gchar *name, gchar **result, gchar **section)
     if (lbrace) {
 	rbrace = strrchr (name, ')');
 	if (rbrace) {
-	    /*sect = g_strndup (lbrace+1, rbrace - lbrace - 1);*/
+	    sect = g_strndup (lbrace+1, rbrace - lbrace - 1);
 	    real_name = g_strndup (name, lbrace - name);
 	} else {
 	    sect = NULL;
@@ -226,12 +233,12 @@ resolve_man_page (const gchar *name, gchar **result, gchar **section)
 	lbrace = strrchr (name, '.');
 	if (lbrace) {
 	    repeat = TRUE;
-	    /*sect = strdup (lbrace+1);*/
+	    sect = strdup (lbrace+1);
 	    real_name = g_strndup (name, lbrace - name);
 	} else {
 	    lbrace = strrchr (name, '#');
 	    if (lbrace) {
-		/*sect = strdup (lbrace+1);*/
+		sect = strdup (lbrace+1);
 		real_name = g_strndup (name, lbrace - name);
 	    } else {
 		real_name = strdup (name);
